@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import datetime
 import types
 import unittest
 
@@ -193,7 +192,7 @@ class TestCollectionReference(unittest.TestCase):
         from google.cloud.firestore_v1.proto import document_pb2
         from google.cloud.firestore_v1.document import DocumentReference
         from google.cloud.firestore_v1 import SERVER_TIMESTAMP
-        from google.cloud.firestore_v1._helpers import pbs_for_set_no_merge
+        from google.cloud.firestore_v1._helpers import pbs_for_create
 
         # Create a minimal fake GAPIC add attach it to a real client.
         firestore_api = mock.Mock(spec=["create_document", "commit"])
@@ -214,42 +213,32 @@ class TestCollectionReference(unittest.TestCase):
         # Actually make a collection.
         collection = self._make_one("grand-parent", "parent", "child", client=client)
 
-        # Add a dummy response for the fake GAPIC.
-        parent_path = collection.parent._document_path
-        auto_assigned_id = "cheezburger"
-        name = "{}/{}/{}".format(parent_path, collection.id, auto_assigned_id)
-        create_doc_response = document_pb2.Document(name=name)
-        create_doc_response.update_time.FromDatetime(datetime.datetime.utcnow())
-        firestore_api.create_document.return_value = create_doc_response
-
         # Actually call add() on our collection; include a transform to make
         # sure transforms during adds work.
         document_data = {"been": "here", "now": SERVER_TIMESTAMP}
-        update_time, document_ref = collection.add(document_data)
+
+        patch = mock.patch("google.cloud.firestore_v1.collection._auto_id")
+        random_doc_id = "DEADBEEF"
+        with patch as patched:
+            patched.return_value = random_doc_id
+            update_time, document_ref = collection.add(document_data)
 
         # Verify the response and the mocks.
         self.assertIs(update_time, mock.sentinel.update_time)
         self.assertIsInstance(document_ref, DocumentReference)
         self.assertIs(document_ref._client, client)
-        expected_path = collection._path + (auto_assigned_id,)
+        expected_path = collection._path + (random_doc_id,)
         self.assertEqual(document_ref._path, expected_path)
 
-        expected_document_pb = document_pb2.Document()
-        firestore_api.create_document.assert_called_once_with(
-            parent_path,
-            collection_id=collection.id,
-            document_id=None,
-            document=expected_document_pb,
-            mask=None,
-            metadata=client._rpc_metadata,
-        )
-        write_pbs = pbs_for_set_no_merge(document_ref._document_path, document_data)
+        write_pbs = pbs_for_create(document_ref._document_path, document_data)
         firestore_api.commit.assert_called_once_with(
             client._database_string,
             write_pbs,
             transaction=None,
             metadata=client._rpc_metadata,
         )
+        # Since we generate the ID locally, we don't call 'create_document'.
+        firestore_api.create_document.assert_not_called()
 
     @staticmethod
     def _write_pb_for_create(document_path, document_data):
